[recipes] Manually roll recipes

This commit changes the layout of recipe_engine a bit which breaks the
autoroller.

  https://crrev.com/095f4b84e4c62983829973f51f0c46f95022806a

R=borenet@google.com, rmistry@google.com

Bug: chromium:913102
Change-Id: Ic6405fbe5ebd00e453677c5050d089e678153d00
Reviewed-on: https://skia-review.googlesource.com/c/175813
Auto-Submit: Robbie Iannucci <iannucci@google.com>
Reviewed-by: Eric Boren <borenet@google.com>
Commit-Queue: Eric Boren <borenet@google.com>
diff --git a/infra/config/recipes.cfg b/infra/config/recipes.cfg
index daaa983..0d87756 100644
--- a/infra/config/recipes.cfg
+++ b/infra/config/recipes.cfg
@@ -14,12 +14,12 @@
   "deps": {
     "depot_tools": {
       "branch": "master",
-      "revision": "4be60eeb2259d04ab82a1f8648b8827134c3e453",
+      "revision": "03ee2d619043c4bacf6b17c4d5cfb3cd607026be",
       "url": "https://chromium.googlesource.com/chromium/tools/depot_tools.git"
     },
     "recipe_engine": {
       "branch": "master",
-      "revision": "7bf15aaea60841beb1973a1b0ec19f3be3ec53b2",
+      "revision": "095f4b84e4c62983829973f51f0c46f95022806a",
       "url": "https://chromium.googlesource.com/infra/luci/recipes-py.git"
     }
   },
diff --git a/infra/bots/recipes.py b/infra/bots/recipes.py
index d726c68..04fb9c9 100755
--- a/infra/bots/recipes.py
+++ b/infra/bots/recipes.py
@@ -10,7 +10,7 @@
 ** DO NOT MODIFY **
 *******************
 
-This is a copy of https://chromium.googlesource.com/infra/luci/recipes-py/+/master/doc/recipes.py.
+This is a copy of https://chromium.googlesource.com/infra/luci/recipes-py/+/master/recipes.py.
 To fix bugs, fix in the googlesource repo then run the autoroller.
 """
 
@@ -73,7 +73,7 @@
       raise MalformedRecipesCfg('unknown version %d' % pb['api_version'],
                                 recipes_cfg_path)
 
-    # If we're running ./doc/recipes.py from the recipe_engine repo itself, then
+    # If we're running ./recipes.py from the recipe_engine repo itself, then
     # return None to signal that there's no EngineDep.
     if pb['project_id'] == 'recipe_engine':
       return None, pb.get('recipes_path', '')
@@ -132,7 +132,7 @@
 def parse_args(argv):
   """This extracts a subset of the arguments that this bootstrap script cares
   about. Currently this consists of:
     * an override for the recipe engine in the form of `-O recipe_engin=/path`
     * the --package option.
   """
   PREFIX = 'recipe_engine='
@@ -211,7 +211,7 @@
 
   return _subprocess_call([
       VPYTHON, '-u',
-      os.path.join(engine_path, 'recipes.py')] + args)
+      os.path.join(engine_path, 'recipe_engine', 'main.py')] + args)
 
 
 if __name__ == '__main__':
@@ -132,7 +132,7 @@
   """This extracts a subset of the arguments that this bootstrap script cares
   about. Currently this consists of:
-    * an override for the recipe engine in the form of `-O recipe_engin=/path`
+    * an override for the recipe engine in the form of `-O recipe_engine=/path`
     * the --package option.
   """